# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-09-10 10:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_leek', '0002_queuedtasks_pool'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queuedtasks',
            name='pickled_task',
            field=models.BinaryField(max_length=5000),
        ),
    ]
