# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-09-05 03:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_leek', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='queuedtasks',
            name='pool',
            field=models.CharField(max_length=256, null=True),
        ),
    ]
